==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/misc/ConditionFlipper.h <==
// public class soot.dava.toolkits.base.misc.ConditionFlipper

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6e0444264d2ced3a soot_dava_toolkits_base_misc_ConditionFlipper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_misc_ConditionFlipper_H_
#define _JC_soot_dava_toolkits_base_misc_ConditionFlipper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_ConditionExpr$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_refs	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_nonrefs	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$refs	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$refs;
typedef struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$nonrefs	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$object	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$object;

typedef const struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vmethods	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtable	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtable;
typedef const struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtype	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_misc_ConditionFlipper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$object *);

// Static methods
extern struct _jc_object *_jc_soot_dava_toolkits_base_misc_ConditionFlipper$method$flip$4f385e5169841472(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vmethods {
};

// Vtable
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$vmethods	soot_dava_toolkits_base_misc_ConditionFlipper;
};

// Vtype
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$refs {
    _jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_refs	soot_dava_toolkits_base_misc_ConditionFlipper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_nonrefs	soot_dava_toolkits_base_misc_ConditionFlipper;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$object {
	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtype	*vtype;
	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtype _jc_soot_dava_toolkits_base_misc_ConditionFlipper$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_misc_ConditionFlipper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_misc_ConditionFlipper$class_object;

#endif	/* _JC_soot_dava_toolkits_base_misc_ConditionFlipper_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/misc/ConditionFlipper.h <==
// public class soot.dava.toolkits.base.misc.ConditionFlipper

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6e0444264d2ced3a soot_dava_toolkits_base_misc_ConditionFlipper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_misc_ConditionFlipper_H_
#define _JC_soot_dava_toolkits_base_misc_ConditionFlipper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_ConditionExpr$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_refs	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_nonrefs	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$refs	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$refs;
typedef struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$nonrefs	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$object	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$object;

typedef const struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vmethods	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtable	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtable;
typedef const struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtype	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_misc_ConditionFlipper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_soot_dava_toolkits_base_misc_ConditionFlipper$method$flip$4f385e5169841472(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vmethods {
};

// Vtable
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$vmethods	soot_dava_toolkits_base_misc_ConditionFlipper;
};

// Vtype
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$refs {
    _jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_refs	soot_dava_toolkits_base_misc_ConditionFlipper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_misc_ConditionFlipper$sub_nonrefs	soot_dava_toolkits_base_misc_ConditionFlipper;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_misc_ConditionFlipper$object {
	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtype	*vtype;
	_jc_soot_dava_toolkits_base_misc_ConditionFlipper$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_misc_ConditionFlipper$vtype _jc_soot_dava_toolkits_base_misc_ConditionFlipper$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_misc_ConditionFlipper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_misc_ConditionFlipper$class_object;

#endif	/* _JC_soot_dava_toolkits_base_misc_ConditionFlipper_H_ */
